#
# spec file for package python-pycryptodomex
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pycryptodomex
%global modname pycryptodomex
Version:        3.4.6
Release:        lp151.2.4
Summary:        Cryptographic library for Python
License:        BSD-2-Clause
Group:          Development/Languages/Python
Url:            https://www.pycryptodome.org
Source:         https://pypi.io/packages/source/p/%{modname}/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%python_subpackages

%description
PyCryptodome is a self-contained Python package of low-level
cryptographic primitives.

* Authenticated encryption modes (GCM, CCM, EAX, SIV, OCB)
* Accelerated AES on Intel platforms via AES-NI
* First class support for PyPy
* Elliptic curves cryptography (NIST P-256 curve only)
* Better and more compact API (`nonce` and `iv` attributes for ciphers,
  automatic generation of random nonces and IVs, simplified CTR cipher mode,
  and more)
* SHA-3 (including SHAKE XOFs) and BLAKE2 hash algorithms
* Salsa20 and ChaCha20 stream ciphers
* scrypt and HKDF
* Deterministic (EC)DSA
* Password-protected PKCS#8 key containers
* Shamir's Secret Sharing scheme
* Random numbers get sourced directly from the OS (and not from a CSPRNG in userspace)
* Simplified install process, including better support for Windows
* Cleaner RSA and DSA key generation (largely based on FIPS 186-4)
* Major clean ups and simplification of the code base

%prep
%setup -q -n %{modname}-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_expand rm -rf %{buildroot}%{$python_sitelib}/Cryptodome/SelfTest/
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%python_exec setup.py test

%files %{python_files}
%defattr(-,root,root,-)
%doc Changelog.rst AUTHORS.rst LICENSE.rst README.rst
%{python_sitearch}/*

%changelog
* Mon Jul 10 2017 okurz@suse.com
- Update to version 3.4.6
  * Resolved issues:
  * GH#65. Keccak, SHA3, SHAKE and the seek functionality for ChaCha20 were
    not working on big endian machines. Fixed. Thanks to Mike Gilbert.
  * A few fixes in the documentation.
* Thu Apr  6 2017 michael@stroeder.com
- Upstream update 3.4.5
- HTTPS project URL
* Tue Nov 22 2016 dmueller@suse.com
- Initial package (3.4.3)
